AlekSIS (School Information System) — App Χρόνος (digital timetables)
=====================================================================

AlekSIS
-------

This is an application for use with the `AlekSIS®`_ platform.

Features
--------

* Consider object-level rules and permissions
* Export timetables as PDF
* Search in rooms
* Show absent groups in timetable
* Show absent teachers in timetable
* Show affected groups in timetable
* Show affected teachers in timetable
* Show supervisions in timetable
* Timetables per day
* Timetables per group
* Timetables per person
* Timetables per room
* Timetables per week
* Smart timetable

Licence
-------

::

  Copyright © 2018, 2019, 2020, 2021, 2022 Jonathan Weth <dev@jonathanweth.de>
  Copyright © 2018, 2019 Frank Poetzsch-Heffter <p-h@katharineum.de>
  Copyright © 2019, 2020, 2022 Dominik George <dominik.george@teckids.org>
  Copyright © 2019, 2021 Hangzhi Yu <yuha@katharineum.de>
  Copyright © 2019 Julian Leucker <leuckeju@katharineum.de>
  Copyright © 2019 Tom Teichler <tom.teichler@teckids.org>
  Copyright © 2021 Lloyd Meins <meinsll@katharineum.de>

  Licenced under the EUPL, version 1.2 or later, by Teckids e.V. (Bonn, Germany).

Please see the LICENCE.rst file accompanying this distribution for the
full licence text or on the `European Union Public Licence`_ website
https://joinup.ec.europa.eu/collection/eupl/guidelines-users-and-developers
(including all other official language versions).

Trademark
---------

AlekSIS® is a registered trademark of the AlekSIS open source project, represented
by Teckids e.V. Please refer to the `trademark policy`_ for hints on using the trademark
AlekSIS®.

.. _AlekSIS®: https://aleksis.org/
.. _European Union Public Licence: https://eupl.eu/
.. _trademark policy: https://aleksis.org/pages/about
